@@ -1,4 +1,4 @@
 from marketools.stock import *
-from marketools.wallet import *
+from marketools import wallet
 from marketools.simulator import simulator
 from marketools.analysis import *
